import codecs
from pathlib import Path
from typing import Optional

from .config import ANNEX_HTML_FILE, OLD_PATH, PONENCIA_HTML_FILE, SC_PATH


def get_source(source: str) -> Optional[Path]:
    if source == "sc":
        return SC_PATH
    if source == "legacy":
        return OLD_PATH
    return None


def get_source_pk(source: str, pk: str) -> Optional[Path]:
    if (parent := get_source(source)) and (folder := parent / pk).exists():
        return folder
    return None


def get_ponencia(source: str, pk: str) -> Optional[str]:
    if (l := get_source_pk(source, pk)) and (content := extract_ponencia(l)):
        return content
    return None


def get_annex(source: str, pk: str) -> Optional[str]:
    if (l := get_source_pk(source, pk)) and (content := extract_annex(l)):
        return content
    return None


def extract_ponencia(folder: Path) -> Optional[str]:
    return get_html(folder / PONENCIA_HTML_FILE)


def extract_annex(folder: Path) -> Optional[str]:
    return get_html(folder / ANNEX_HTML_FILE)


def get_html(loc: Path) -> Optional[str]:
    return codecs.open(str(loc), "r").read() if loc.exists() else None
