import re
from typing import Match, Optional

from casereports.__main__ import page, volume
from casereports.base.phil import phil
from casereports.base.scra import scra

from .config import DECISIONS, MatchedRows

SCRA = re.compile(
    rf"""(
        {volume}
        \s+
        {scra}
        \s+
        {page}
    )
    """,
    re.I | re.X,
)

PHIL = re.compile(
    rf"""(
        {volume}
        \s+
        {phil}
        \s+
        {page}
    )
    """,
    re.I | re.X,
)


def _match_query(qs: str, p: str) -> MatchedRows:
    "Results of database query (with query string and parameters) to produce MatchedRow with .counts and .rows"
    return MatchedRows(DECISIONS.count_where(qs, p), DECISIONS.rows_where(qs, p))


def _format_parameter_string(match: Match, publisher_format: str) -> str:
    "Converts matched citation to format stored in database"
    return f"{match.group('volume')} {publisher_format} {match.group('page')}"


def rows_from_phil(text: str) -> Optional[MatchedRows]:
    "Get results from database if the text matches the Phil. report pattern."
    return (
        _match_query("phil = ?", _format_parameter_string(m, "Phil."))
        if (m := PHIL.search(text))
        else None
    )


def rows_from_scra(text: str) -> Optional[MatchedRows]:
    "Get results from database if the text matches the SCRA report pattern."
    return (
        _match_query("scra = ?", _format_parameter_string(m, "SCRA"))
        if (m := SCRA.search(text))
        else None
    )


def rows_from_report_text(text: str) -> Optional[MatchedRows]:
    return rows_from_phil(text) or rows_from_scra(text)
